@@ -6,10 +6,24 @@ use Robotics;
 use Robotics::Tecan;
 
 print "Testing Robotics $Robotics::VERSION, Perl $], $^X\n";
-
-my $hw = Robotics::Tecan->new(
-    'server' => 'heavybio.dyndns.org:8088',
-    'password' => $ENV{'TECANPASSWORD'});
+my $obj = Robotics->new();
+print "Hardware: ". $obj->printDevices();
+my $gemini;
+my $hw;
+if ($gemini = $obj->findDevice(product => "Gemini")) { 
+    print "Found local Gemini $gemini\n";
+    my $genesis = $obj->findDevice(product => "Genesis");
+    $hw = Robotics::Tecan->new(
+        connection => $gemini);
+}
+else {
+    print "No Gemini found, opening network client\n";
+    $hw = Robotics::Tecan->new(
+        connection => 'network,Robotics::Tecan::Genesis,genesis0',
+        token => 'M1',
+        serveraddr => 'heavybio.dyndns.org:8088',
+        password => $ENV{'TECANPASSWORD'});
+}
 
 if (!$hw) { 
     die "fail to connect\n";
@@ -17,6 +31,7 @@ if (!$hw) {
 
 $hw->attach();
 $_ = $hw->status();
+print;
 exit -2 if !/IDLE/i;
 
 warn "
@@ -60,8 +75,9 @@ sub Main {
 
     $hw->status();
     $_ = $hw->initialize();
+    #exit -3 if !/IDLE/i;
+    $_ = $hw->status();
     exit -3 if !/IDLE/i;
-    $hw->status();
 
     $hw->park("roma0");
     checkerr7 $hw->move("roma0", "nonesuch-expect-error7");
